BottomNavigationController class

A controller that manages the state of a bottom navigation bar.

This controller tracks the current selected index and notifies listeners when the index changes. It is used by BottomNavigationScope to coordinate between StacBottomNavigationBar and StacBottomNavigationView.

Inheritance

Constructors

BottomNavigationController({int initialIndex = 0, required int length})
Creates a BottomNavigationController with the specified properties.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
index int
The current selected index.
getter/setter pair
initialIndex int
The initial index when the controller is created.
final
length int
The number of navigation items.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited