StacBorderStyle enum

Border style options for drawing borders.

Inheritance
Available extensions

Values

none → const StacBorderStyle

Skip the border.

solid → const StacBorderStyle

Draw the border as a solid line.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse BorderStyle

Available on StacBorderStyle, provided by the StacBorderStyleParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacBorderStyle>
A constant List of the values in this enum, in order of their declaration.