StacBottomNavigationBarLandscapeLayout enum

Enum mirroring Flutter's BottomNavigationBarLandscapeLayout.

  • spread: Items are spread across available width.
  • centered: Items are centered.
  • linear: Items are laid out linearly.
Inheritance
  • Object
  • Enum
  • StacBottomNavigationBarLandscapeLayout
Available extensions

Values

spread → const StacBottomNavigationBarLandscapeLayout

Spread items across the available width.

centered → const StacBottomNavigationBarLandscapeLayout

Center items within the available width.

linear → const StacBottomNavigationBarLandscapeLayout

Lay out items linearly without spreading.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse BottomNavigationBarLandscapeLayout

Available on StacBottomNavigationBarLandscapeLayout, provided by the StacBottomNavigationBarLandscapeLayoutParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacBottomNavigationBarLandscapeLayout>
A constant List of the values in this enum, in order of their declaration.