StacBrightness enum

Mirrors Flutter's Brightness.

Inheritance
Available extensions

Values

light → const StacBrightness

Light mode.

dark → const StacBrightness

Dark mode.

system → const StacBrightness

System default (treated as light/dark based on platform theme).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse Brightness

Available on StacBrightness, provided by the StacBrightnessParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacBrightness>
A constant List of the values in this enum, in order of their declaration.