StacButtonBarLayoutBehavior enum

Button bar layout behavior options.

Defines how button bars are laid out.

Inheritance
Available extensions

Values

constrained → const StacButtonBarLayoutBehavior

Button bars will be constrained to a minimum height of 52.

This setting is required to create button bars which conform to the Material Design specification.

padded → const StacButtonBarLayoutBehavior

Button bars will be padded.

This is the default behavior.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse ButtonBarLayoutBehavior

Available on StacButtonBarLayoutBehavior, provided by the StacButtonBarLayoutBehaviorParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacButtonBarLayoutBehavior>
A constant List of the values in this enum, in order of their declaration.