StacCircleBorder class

A Stac model representing Flutter's CircleBorder.

A circular border, typically used with ShapeDecoration to draw a box with a circular shape.

StacCircleBorder(
  side: StacBorderSide(width: 1.0, color: StacColors.grey),
)
{
  "type": "circleBorder",
  "side": {"width": 1.0, "color": "#808080"}
}
Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

StacCircleBorder({StacBorderSide? side, double? eccentricity})
Creates a StacCircleBorder with the given properties.
const
StacCircleBorder.fromJson(Map<String, dynamic> json)
Creates a StacCircleBorder from JSON.
factory

Properties

eccentricity → double?
The eccentricity of the circle.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
side → StacBorderSide?
The border side properties.
finalinherited
type → StacShapeBorderType
The type identifier for this shape border. Must be implemented by subclasses.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BuildContext context) → CircleBorder

Available on StacCircleBorder, provided by the StacCircleBorderParser extension

parse(BuildContext context) → OutlinedBorder

Available on StacShapeBorder, provided by the StacShapeBorderParser extension

toJson() → Map<String, dynamic>
Converts this circle border to JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited