StacColor typedef

StacColor = String

Type alias for Stac color representation as a hex string.

Colors in the Stac framework are represented as hex strings (e.g., '#FF0000') or theme color names (e.g., 'primary', 'secondary').

Implementation

typedef StacColor = String;