StacDatePickerThemeData class

A Stac model representing Flutter's DatePickerThemeData.

Defines the theme for date pickers, including colors, elevation, shapes, text styles for headers, days, years, and range picker properties.

{@tool snippet} Dart Example:

StacDatePickerThemeData(
  backgroundColor: '#FFFFFF',
  elevation: 24.0,
  headerBackgroundColor: '#2196F3',
)

{@end-tool}

{@tool snippet} JSON Example:

{
  "backgroundColor": "#FFFFFF",
  "elevation": 24.0,
  "shadowColor": "#000000",
  "headerBackgroundColor": "#2196F3",
  "headerForegroundColor": "#FFFFFF"
}

{@end-tool}

Implemented types
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

StacDatePickerThemeData({String? backgroundColor, double? elevation, String? shadowColor, String? surfaceTintColor, StacShapeBorder? shape, String? headerBackgroundColor, String? headerForegroundColor, StacTextStyle? headerHeadlineStyle, StacTextStyle? headerHelpStyle, StacTextStyle? weekdayStyle, StacTextStyle? dayStyle, String? dayForegroundColor, String? dayBackgroundColor, String? dayOverlayColor, StacShapeBorder? dayShape, String? todayForegroundColor, String? todayBackgroundColor, StacBorderSide? todayBorder, StacTextStyle? yearStyle, String? yearForegroundColor, String? yearBackgroundColor, String? yearOverlayColor, String? rangePickerBackgroundColor, double? rangePickerElevation, String? rangePickerShadowColor, String? rangePickerSurfaceTintColor, StacShapeBorder? rangePickerShape, String? rangePickerHeaderBackgroundColor, String? rangePickerHeaderForegroundColor, StacTextStyle? rangePickerHeaderHeadlineStyle, StacTextStyle? rangePickerHeaderHelpStyle, String? rangeSelectionBackgroundColor, String? rangeSelectionOverlayColor, String? dividerColor, StacInputDecorationTheme? inputDecorationTheme, StacButtonStyle? cancelButtonStyle, StacButtonStyle? confirmButtonStyle})
Creates a StacDatePickerThemeData with the given properties.
const
StacDatePickerThemeData.fromJson(Map<String, dynamic> json)
Creates a StacDatePickerThemeData from JSON.
factory

Properties

backgroundColor → String?
The background color of the date picker.
final
cancelButtonStyle → StacButtonStyle?
The button style for the cancel button.
final
confirmButtonStyle → StacButtonStyle?
The button style for the confirm button.
final
dayBackgroundColor → String?
The background color for day cells.
final
dayForegroundColor → String?
The foreground color for day cells.
final
dayOverlayColor → String?
The overlay color for day cells.
final
dayShape → StacShapeBorder?
The shape of day cell borders.
final
dayStyle → StacTextStyle?
The text style for day labels.
final
dividerColor → String?
The color of dividers in the date picker.
final
elevation → double?
The z-coordinate at which to place this date picker relative to its parent.
final
hashCode → int
The hash code for this object.
no setterinherited
headerBackgroundColor → String?
The background color of the date picker header.
final
headerForegroundColor → String?
The foreground color of the date picker header.
final
headerHeadlineStyle → StacTextStyle?
The text style for the date picker header headline.
final
headerHelpStyle → StacTextStyle?
The text style for the date picker header help text.
final
inputDecorationTheme → StacInputDecorationTheme?
The input decoration theme for date picker inputs.
final
rangePickerBackgroundColor → String?
The background color of the range picker.
final
rangePickerElevation → double?
The z-coordinate at which to place the range picker.
final
rangePickerHeaderBackgroundColor → String?
The background color of the range picker header.
final
rangePickerHeaderForegroundColor → String?
The foreground color of the range picker header.
final
rangePickerHeaderHeadlineStyle → StacTextStyle?
The text style for the range picker header headline.
final
rangePickerHeaderHelpStyle → StacTextStyle?
The text style for the range picker header help text.
final
rangePickerShadowColor → String?
The color of the shadow below the range picker.
final
rangePickerShape → StacShapeBorder?
The shape of the range picker's border.
final
rangePickerSurfaceTintColor → String?
The color used to tint the surface of the range picker.
final
rangeSelectionBackgroundColor → String?
The background color for range selection.
final
rangeSelectionOverlayColor → String?
The overlay color for range selection.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → String?
The color of the shadow below the date picker.
final
shape → StacShapeBorder?
The shape of the date picker's border.
final
surfaceTintColor → String?
The color used to tint the surface of this date picker.
final
todayBackgroundColor → String?
The background color for today's date.
final
todayBorder → StacBorderSide?
The border for today's date.
final
todayForegroundColor → String?
The foreground color for today's date.
final
weekdayStyle → StacTextStyle?
The text style for weekday labels.
final
yearBackgroundColor → String?
The background color for year cells.
final
yearForegroundColor → String?
The foreground color for year cells.
final
yearOverlayColor → String?
The overlay color for year cells.
final
yearStyle → StacTextStyle?
The text style for year labels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BuildContext context) → DatePickerThemeData

Available on StacDatePickerThemeData, provided by the StacDatePickerThemeDataParser extension

toJson() → Map<String, dynamic>
Converts this date picker theme to JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited