StacDropdownMenuCloseBehavior enum
Controls how a DropdownMenu responds to taps outside of it.
Values
- all → const StacDropdownMenuCloseBehavior
-
Close when tapping anywhere.
- self → const StacDropdownMenuCloseBehavior
-
Close only when tapping the menu itself.
- none → const StacDropdownMenuCloseBehavior
-
Do not close automatically.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StacDropdownMenuCloseBehavior> - A constant List of the values in this enum, in order of their declaration.