type property

  1. @override
String get type
override

The type of the model that this parser can parse.

This is used to identify the type of the model in the JSON object.

Implementation

@override
String get type => WidgetType.filledButton.name;