StacIconThemeData class

A Stac model representing Flutter's IconThemeData.

Defines the theme for icons, including size, color, opacity, and visual properties.

{@tool snippet} Dart Example:

StacIconThemeData(
  color: '#2196F3',
  size: 24.0,
  opacity: 1.0,
)

{@end-tool}

{@tool snippet} JSON Example:

{
  "color": "#2196F3",
  "size": 24.0,
  "opacity": 1.0,
  "fill": 0.0,
  "weight": 400.0,
  "grade": 0.0,
  "opticalSize": 24.0
}

{@end-tool}

Implemented types
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

StacIconThemeData({double? size, double? fill, double? weight, double? grade, double? opticalSize, String? color, double? opacity, List<StacShadow>? shadows})
Creates a StacIconThemeData with the given properties.
const
StacIconThemeData.fromJson(Map<String, dynamic> json)
Creates a StacIconThemeData from JSON.
factory

Properties

color String?
The color of the icon.
final
fill double?
The fill value for the icon (0.0 to 1.0).
final
grade double?
The grade value for the icon (-25 to 200).
final
hashCode int
The hash code for this object.
no setterinherited
opacity double?
The opacity of the icon (0.0 to 1.0).
final
opticalSize double?
The optical size for the icon in logical pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadows List<StacShadow>?
The list of shadows to apply to the icon.
final
size double?
The size of the icon in logical pixels.
final
weight double?
The weight value for the icon (100 to 900).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BuildContext context) IconThemeData?

Available on StacIconThemeData, provided by the StacIconThemeDataParser extension

toJson() Map<String, dynamic>
Converts this icon theme to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited