StacInputBorderType enum
Type of input border to render.
Mirrors Flutter's InputBorder variants commonly used by text fields.
- none: Renders no border.
- underlineInputBorder: Renders a Material underline-style border.
- outlineInputBorder: Renders a rounded rectangle outline border.
Values
- none → const StacInputBorderType
-
Renders no border.
- underlineInputBorder → const StacInputBorderType
-
Renders a Material underline-style border.
- outlineInputBorder → const StacInputBorderType
-
Renders a rounded rectangle outline border.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StacInputBorderType> - A constant List of the values in this enum, in order of their declaration.