StacListTileThemeData class

A Stac model representing Flutter's ListTileThemeData.

Defines the theme for list tiles, including colors, text styles, layout, and visual properties.

{@tool snippet} Dart Example:

StacListTileThemeData(
  tileColor: '#FFFFFF',
  selectedTileColor: '#E3F2FD',
  dense: false,
)

{@end-tool}

{@tool snippet} JSON Example:

{
  "tileColor": "#FFFFFF",
  "selectedTileColor": "#E3F2FD",
  "dense": false,
  "style": "list",
  "iconColor": "#757575",
  "textColor": "#212121"
}

{@end-tool}

Implemented types
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

StacListTileThemeData({bool? dense, StacBorder? shape, StacListTileStyle? style, String? selectedColor, String? iconColor, String? textColor, StacTextStyle? titleTextStyle, StacTextStyle? subtitleTextStyle, StacTextStyle? leadingAndTrailingTextStyle, StacEdgeInsets? contentPadding, String? tileColor, String? selectedTileColor, double? horizontalTitleGap, double? minVerticalPadding, double? minLeadingWidth, bool? enableFeedback, StacVisualDensity? visualDensity, StacListTileTitleAlignment? titleAlignment, List<StacShadow>? shadows})
Creates a StacListTileThemeData with the given properties.
const
StacListTileThemeData.fromJson(Map<String, dynamic> json)
Creates a StacListTileThemeData from JSON.
factory

Properties

contentPadding StacEdgeInsets?
The padding around the list tile's content.
final
dense bool?
Whether to use a more compact layout for the list tile.
final
enableFeedback bool?
Whether detected gestures should provide acoustic and/or haptic feedback.
final
hashCode int
The hash code for this object.
no setterinherited
horizontalTitleGap double?
The horizontal gap between the leading widget and the title.
final
iconColor String?
The color to use for list tile icons.
final
leadingAndTrailingTextStyle StacTextStyle?
The text style for leading and trailing widgets.
final
minLeadingWidth double?
The minimum width for the leading widget.
final
minVerticalPadding double?
The minimum vertical padding for the list tile.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor String?
The color to use for selected list tiles.
final
selectedTileColor String?
The background color of the selected list tile.
final
shadows List<StacShadow>?
The list of shadows to apply to the list tile.
final
shape StacBorder?
The shape of the list tile's border.
final
style StacListTileStyle?
The style of the list tile.
final
subtitleTextStyle StacTextStyle?
The text style for the list tile's subtitle.
final
textColor String?
The color to use for list tile text.
final
tileColor String?
The background color of the list tile.
final
titleAlignment StacListTileTitleAlignment?
The alignment of the list tile's title.
final
titleTextStyle StacTextStyle?
The text style for the list tile's title.
final
visualDensity StacVisualDensity?
The visual density of the list tile.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BuildContext context) ListTileThemeData

Available on StacListTileThemeData, provided by the StacListTileThemeDataParser extension

toJson() Map<String, dynamic>
Converts this list tile theme to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited