StacMainAxisSize enum

Main-axis sizing options for flex layouts.

Defines how much space a flex layout should occupy along its main axis. This affects the overall size of flex containers like Row and Column:

  • In a Row, controls the horizontal space occupied
  • In a Column, controls the vertical space occupied

Use min to minimize space usage and max to expand to fill available space.

Inheritance
Available extensions

Values

min → const StacMainAxisSize

Minimize the space occupied along the main axis.

The flex layout will only take up as much space as needed to fit its children. This is useful when you want the layout to be as compact as possible.

max → const StacMainAxisSize

Maximize the space occupied along the main axis.

The flex layout will expand to fill all available space along the main axis. This is useful when you want the layout to take up the full width (Row) or height (Column) of its parent.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse MainAxisSize

Available on StacMainAxisSize, provided by the StacMainAxisSizeParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacMainAxisSize>
A constant List of the values in this enum, in order of their declaration.