StacMaterialTapTargetSize enum

Material tap target size options.

Defines the minimum size of the tap target area.

Inheritance
Available extensions

Values

padded → const StacMaterialTapTargetSize

Tap target is padded to meet minimum size requirements.

shrinkWrap → const StacMaterialTapTargetSize

Tap target shrinks to fit the button content.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse MaterialTapTargetSize

Available on StacMaterialTapTargetSize, provided by the StacMaterialTapTargetSizeParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacMaterialTapTargetSize>
A constant List of the values in this enum, in order of their declaration.