StacParser<T> class abstract

StacParser is an abstract class that is used to parse a JSON object into a model and then parse the model into a widget.

This is used to create a parser for each type of STAC item asset. For example, a StacTextParser can be used to parse a STAC item asset with a "type": "text" field into a Text widget.

Implementers

Constructors

StacParser()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of the model that this parser can parse.
no setter

Methods

getModel(Map<String, dynamic> json) → T
Parses a JSON object into a model T.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BuildContext context, T model) Widget
Parses a model T into a Widget.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited