StacRefreshIndicatorTriggerMode enum

Defines how the StacRefreshIndicator can be triggered, mirroring Flutter's RefreshIndicatorTriggerMode.

Inheritance
Available extensions

Values

onEdge → const StacRefreshIndicatorTriggerMode

The indicator can be triggered when the scrollable reaches the edge. This corresponds to RefreshIndicatorTriggerMode.onEdge.

anywhere → const StacRefreshIndicatorTriggerMode

The indicator can be triggered anywhere in the scrollable. This corresponds to RefreshIndicatorTriggerMode.anywhere.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse RefreshIndicatorTriggerMode

Available on StacRefreshIndicatorTriggerMode, provided by the StacRefreshIndicatorTriggerModeParser extension

Parses this StacRefreshIndicatorTriggerMode into a Flutter RefreshIndicatorTriggerMode.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacRefreshIndicatorTriggerMode>
A constant List of the values in this enum, in order of their declaration.