StacRoundedRectangleBorder class

A Stac model representing Flutter's RoundedRectangleBorder.

A rectangular border with rounded corners, typically used with ShapeDecoration to draw a box with a rounded rectangle.

StacRoundedRectangleBorder(
  borderRadius: StacBorderRadius.all(8.0),
  side: StacBorderSide(width: 1.0, color: StacColors.grey),
)
{
  "type": "roundedRectangle",
  "borderRadius": {"all": 8.0},
  "side": {"width": 1.0, "color": "#808080"}
}
Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

StacRoundedRectangleBorder({StacBorderSide? side, StacBorderRadius? borderRadius})
Creates a StacRoundedRectangleBorder with the given properties.
const
StacRoundedRectangleBorder.fromJson(Map<String, dynamic> json)
Creates a StacRoundedRectangleBorder from JSON.
factory

Properties

borderRadius → StacBorderRadius?
The border radius for the rounded corners.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
side → StacBorderSide?
The border side properties.
finalinherited
type → StacShapeBorderType
The type identifier for this shape border. Must be implemented by subclasses.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BuildContext context) → RoundedRectangleBorder

Available on StacRoundedRectangleBorder, provided by the StacRoundedRectangleBorderParser extension

parse(BuildContext context) → OutlinedBorder

Available on StacShapeBorder, provided by the StacShapeBorderParser extension

toJson() → Map<String, dynamic>
Converts this rounded rectangle border to JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited