height property
The height of the box. If null, the box will try to be as high as its parent allows.
Implementation
@DoubleConverter()
final double? height;
The height of the box. If null, the box will try to be as high as its parent allows.
@DoubleConverter()
final double? height;