StacSliderType enum
An enum to select which platform style of Slider to render.
Mirrors the variants supported by Flutter and used by the parser to decide which widget implementation to build.
Values
- adaptive → const StacSliderType
-
Use an adaptive slider that selects a platform-appropriate implementation (e.g., Material on Android, Cupertino on iOS).
- cupertino → const StacSliderType
-
Always render a Cupertino-styled slider.
- material → const StacSliderType
-
Always render a Material-styled slider.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StacSliderType> - A constant List of the values in this enum, in order of their declaration.