mainAxisSpacing property
The amount of space between children in the main axis.
Defaults to 0.0.
Implementation
@DoubleConverter()
final double? mainAxisSpacing;
The amount of space between children in the main axis.
Defaults to 0.0.
@DoubleConverter()
final double? mainAxisSpacing;