parse method

  1. @override
Widget parse(
  1. BuildContext context,
  2. StacSliverPadding model
)
override

Parses a model T into a Widget.

This method should be implemented to parse a model into a widget. The model T is the result of the getModel method. The BuildContext is the current build context.

Implementation

@override
Widget parse(BuildContext context, StacSliverPadding model) {
  return SliverPadding(
    padding: model.padding.parse,
    sliver: model.sliver.parse(context),
  );
}