StacTabAlignment enum

Controls how tabs are aligned within a TabBar.

Maps to Flutter's TabAlignment (Material 3).

Inheritance
Available extensions

Values

start → const StacTabAlignment

Align tabs to the start.

startOffset → const StacTabAlignment

Align tabs to the start with additional offset behavior.

fill → const StacTabAlignment

Stretch tabs to fill the available width.

center → const StacTabAlignment

Center tabs in the available width.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse TabAlignment

Available on StacTabAlignment, provided by the StacTabAlignmentParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacTabAlignment>
A constant List of the values in this enum, in order of their declaration.