StacTabBarViewParser class
- Inheritance
-
- Object
- StacParser<
StacTabBarView> - StacTabBarViewParser
Constructors
- StacTabBarViewParser({TabController? controller})
-
const
Properties
- controller → TabController?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The
typeof the model that this parser can parse.no setteroverride
Methods
-
getModel(
Map< String, dynamic> json) → StacTabBarView -
Parses a JSON object into a model
T.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
BuildContext context, StacTabBarView model) → Widget -
Parses a model
Tinto a Widget.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited