verticalAlignment property
How the child should be aligned vertically within the cell.
Implementation
final StacTableCellVerticalAlignment? verticalAlignment;
How the child should be aligned vertically within the cell.
final StacTableCellVerticalAlignment? verticalAlignment;