StacTableCellVerticalAlignment enum

Vertical alignment options for table cells.

Mirrors Flutter's TableCellVerticalAlignment and controls how the child of a table cell is positioned vertically within the row height.

Inheritance
Available extensions

Values

top → const StacTableCellVerticalAlignment

Align at the top of the row.

middle → const StacTableCellVerticalAlignment

Center vertically within the row.

bottom → const StacTableCellVerticalAlignment

Align at the bottom of the row.

baseline → const StacTableCellVerticalAlignment

Align the baselines of text for the row.

fill → const StacTableCellVerticalAlignment

Expand to fill the full height of the row.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse TableCellVerticalAlignment

Available on StacTableCellVerticalAlignment?, provided by the StacTableCellVerticalAlignmentParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacTableCellVerticalAlignment>
A constant List of the values in this enum, in order of their declaration.