StacTextAlign enum

Text alignment options for text widgets.

Inheritance
Available extensions

Values

left → const StacTextAlign

Align text to the left edge.

Align text to the right edge.

center → const StacTextAlign

Center text horizontally.

justify → const StacTextAlign

Justify text to fill the available width.

start → const StacTextAlign

Align text to the start edge (left in LTR, right in RTL).

end → const StacTextAlign

Align text to the end edge (right in LTR, left in RTL).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse TextAlign

Available on StacTextAlign, provided by the StacTextAlignParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacTextAlign>
A constant List of the values in this enum, in order of their declaration.