StacTextDecorationStyle enum
Text decoration style options for underlines, overlines, etc.
- Inheritance
- Available extensions
Values
- solid → const StacTextDecorationStyle
-
Solid line decoration.
- double → const StacTextDecorationStyle
-
Double line decoration.
- dotted → const StacTextDecorationStyle
-
Dotted line decoration.
- dashed → const StacTextDecorationStyle
-
Dashed line decoration.
- wavy → const StacTextDecorationStyle
-
Wavy line decoration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - parse → TextDecorationStyle
-
Available on StacTextDecorationStyle, provided by the StacTextDecorationStyleParser extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StacTextDecorationStyle> - A constant List of the values in this enum, in order of their declaration.