StacTileMode enum

Tile modes that determine how gradients handle areas outside their defined bounds.

Inheritance
Available extensions

Values

clamp → const StacTileMode

Clamp the gradient to the edge colors.

repeated → const StacTileMode

Repeat the gradient pattern.

mirror → const StacTileMode

Mirror the gradient pattern.

decal → const StacTileMode

Use transparent pixels outside the gradient bounds.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
parse TileMode

Available on StacTileMode, provided by the StacTileModeParser extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StacTileMode>
A constant List of the values in this enum, in order of their declaration.