showDuration property

StacDuration? showDuration
final

The length of time that the tooltip will be shown after a long press is released (if triggerMode is StacTooltipTriggerMode.longPress) or a tap is released (if triggerMode is StacTooltipTriggerMode.tap).

Defined in milliseconds.

Implementation

final StacDuration? showDuration;