StacTooltipTriggerMode enum
Defines the interaction method that triggers a tooltip, mirroring Flutter's TooltipTriggerMode.
- Inheritance
- Available extensions
Values
- manual → const StacTooltipTriggerMode
-
Tooltip will only be shown by calling
ensureTooltipVisible. This corresponds to TooltipTriggerMode.manual. - longPress → const StacTooltipTriggerMode
-
Tooltip will be shown after a long press. This corresponds to TooltipTriggerMode.longPress.
- tap → const StacTooltipTriggerMode
-
Tooltip will be shown after a single tap. This corresponds to TooltipTriggerMode.tap.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - parse → TooltipTriggerMode
-
Available on StacTooltipTriggerMode, provided by the StacTooltipTriggerModeParser extension
Parses this StacTooltipTriggerMode into a Flutter TooltipTriggerMode.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StacTooltipTriggerMode> - A constant List of the values in this enum, in order of their declaration.