StacVerticalDivider class

A Stac model representing Flutter's VerticalDivider widget.

A thin vertical line, with padding on either side.

In the material design language, this represents a divider. Vertical dividers are typically used to divide parts of a layout.

The box's width is controlled by the width property, and its height is the height of the constraints imposed by its parent.

{@tool snippet} Dart Example:

StacVerticalDivider(
  width: 20.0,
  thickness: 2.0,
  indent: 10.0,
  endIndent: 10.0,
  color: StacColor(value: 0xFF000000),
)

{@end-tool}

{@tool snippet} JSON Example:

{
  "type": "verticalDivider",
  "width": 20.0,
  "thickness": 2.0,
  "indent": 10.0,
  "endIndent": 10.0,
  "color": {"value": 4278190080}
}

{@end-tool}

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

StacVerticalDivider({double? width, double? thickness, double? indent, double? endIndent, StacColor? color})
Creates a StacVerticalDivider.
const
StacVerticalDivider.fromJson(Map<String, dynamic> json)
Creates a StacVerticalDivider instance from a JSON map.
factory

Properties

color → StacColor?
The color to use when painting the line.
final
endIndent → double?
The amount of empty space to the trailing edge of the divider.
final
hashCode → int
The hash code for this object.
no setterinherited
indent → double?
The amount of empty space to the leading edge of the divider.
final
jsonData → Map<String, dynamic>?
Raw JSON data for this widget
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double?
The thickness of the line drawn within the divider.
final
type → String
The type of this Stac widget.
no setteroverride
width → double?
The divider's width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BuildContext context) → Widget?

Available on StacWidget?, provided by the StacWidgetParser extension

parsePreferredSizeWidget(BuildContext context) → PreferredSizeWidget?

Available on StacWidget?, provided by the StacWidgetParser extension

toJson() → Map<String, dynamic>
Converts this StacVerticalDivider instance to a JSON map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited