stac library
Classes
- A controller that manages the state of a navigation widget.
- An inherited widget that exposes navigation state (selected index) to descendant widgets such as StacNavigationBar, StacBottomNavigationBar and StacNavigationView.
- Stac
- The main entry point for rendering Server-Driven UI from Stac Cloud.
- StacAction
- Base class for all Stac actions that can be performed on widgets.
-
StacActionParser<
T> - StacActionParser is an abstract class that is used to parse a JSON object into a model and then handle an action based on the model.
- StacAlertDialog
- A Stac model representing Flutter's AlertDialog widget.
- StacAlertDialogParser
- StacAlign
- A Stac model representing Flutter's Align widget.
- StacAlignmentGeometry
- A Stac representation of Flutter's AlignmentGeometry class.
- StacAlignParser
- StacApp
- StacAppBar
- A Stac model representing Flutter's AppBar widget.
- StacAppBarTheme
- A Stac model representing Flutter's AppBarTheme.
- StacAppTheme
- Provides helpers to load StacTheme definitions for StacApp.
- StacAspectRatio
- A Stac model representing Flutter's AspectRatio widget.
- StacAspectRatioParser
- StacAutoComplete
- A Stac model representing Flutter's Autocomplete widget.
- StacAutoCompleteParser
- StacBackdropFilter
- A Stac model representing Flutter's BackdropFilter widget.
- StacBackdropFilterParser
- StacBadge
- A Stac model representing Flutter's Badge widget.
- StacBadgeParser
- StacBeveledRectangleBorder
- A Stac model representing Flutter's BeveledRectangleBorder.
- StacBorder
- A Stac representation of borders for UI elements.
- StacBorderRadius
- A Stac representation of border radius for rounded corners.
- StacBorderSide
- A Stac representation of a single border side.
- StacBottomAppBarThemeData
- A Stac model representing Flutter's BottomAppBarTheme.
- A Stac model representing Flutter's BottomNavigationBarThemeData.
- A Stac model representing Flutter's BottomNavigationBar.
- A Stac model representing a Flutter BottomNavigationBarItem.
- A Stac model representing a custom Bottom Navigation view container.
-
Parser for the deprecated
bottomNavigationViewwidget type. Delegates to StacNavigationViewParser so it shares behavior with the new genericnavigationView. - StacBottomSheetThemeData
- A Stac model representing Flutter's BottomSheetThemeData.
- StacBoxConstraints
- A Stac representation of box constraints for layout sizing.
- StacBoxDecoration
- A Stac representation of box decoration for styling containers.
- StacBoxShadow
- A Stac representation of box shadows for visual depth effects.
- StacButtonStyle
- A Stac model representing Flutter's ButtonStyle.
- StacButtonThemeData
- A Stac model representing Flutter's ButtonThemeData.
- StacCache
- Model representing a cached screen from Stac Cloud.
- StacCacheConfig
- Configuration for Stac screen caching behavior.
- StacCacheService
- Service for managing cached Stac artifacts (screens, themes, etc.).
- StacCard
- A Stac model representing Flutter's Card widget.
- StacCardParser
- StacCardThemeData
- A Stac model representing Flutter's CardThemeData.
- StacCarouselView
- A Stac model representing Flutter's CarouselView widget.
- StacCarouselViewParser
- StacCenter
- A Stac model representing Flutter's Center widget.
- StacCenterParser
- StacCheckBox
- A Stac model representing Flutter's Checkbox widget.
- StacCheckBoxParser
- StacCheckboxThemeData
- A Stac model representing Flutter's CheckboxThemeData.
- StacChip
- A Stac model representing Flutter's Chip widget.
- StacChipParser
- StacChipThemeData
- A Stac model representing Flutter's ChipThemeData.
- StacCircleAvatar
- A Stac model representing Flutter's CircleAvatar widget.
- StacCircleAvatarParser
- StacCircleBorder
- A Stac model representing Flutter's CircleBorder.
- StacCircularProgressIndicator
- A Stac model representing Flutter's CircularProgressIndicator widget.
- StacCircularProgressIndicatorParser
- StacClipOval
- A Stac model representing Flutter's ClipOval widget.
- StacClipOvalParser
- StacClipRRect
- A Stac model representing Flutter's ClipRRect widget.
- StacClipRRectParser
- StacColoredBox
- A Stac model representing Flutter's ColoredBox widget.
- StacColoredBoxParser
- StacColors
- A collection of predefined colors for the Stac framework.
- StacColorScheme
- A Stac model representing Flutter's ColorScheme.
- StacColumn
- A Stac model representing Flutter's Column widget.
- StacColumnParser
- StacConditional
- A Stac model representing a conditional widget.
- StacConditionalParser
- StacContainer
- A Stac model representing Flutter's Container widget.
- StacContainerParser
- StacContinuousRectangleBorder
- A Stac model representing Flutter's ContinuousRectangleBorder.
- StacCupertinoIcons
- StacCustomScrollView
- A Stac model representing Flutter's CustomScrollView.
- StacCustomScrollViewParser
- StacCustomTextStyle
-
A custom text style similar to Flutter's
TextStyle. - StacDatePickerThemeData
- A Stac model representing Flutter's DatePickerThemeData.
- StacDecorationImage
- An image to use as decoration in a box decoration.
- A Stac model representing Flutter's DefaultTabController widget for bottom navigation.
-
Parser for the deprecated
defaultBottomNavigationControllerwidget type. Delegates to StacDefaultNavigationControllerParser so that the new NavigationScope / NavigationController are produced and remain interoperable with non-deprecated consumers. -
A Stac widget that provides a controller for managing navigation state
(current selected index) and exposes a
NavigationScopeto descendants. - StacDefaultTabController
- A Stac model representing Flutter's DefaultTabController widget.
- StacDefaultTabControllerParser
- StacDelayAction
- Simple delay action that waits for a number of milliseconds.
- StacDelayActionParser
- StacDialogAction
- Core model for the "showDialog" action.
- StacDialogActionParser
- StacDialogTheme
- A Stac model representing Flutter's DialogTheme.
- StacDialogThemeData
- A Stac model representing Flutter's DialogThemeData.
- StacDivider
- A Stac model representing Flutter's Divider widget.
- StacDividerParser
- StacDividerThemeData
- A Stac model representing Flutter's DividerThemeData.
- StacDrawer
- A Stac model representing Flutter's Drawer widget.
- StacDrawerParser
- StacDrawerThemeData
- A Stac model representing Flutter's DrawerThemeData.
- StacDropdownMenu
- A Stac model representing Flutter's DropdownMenu widget.
- StacDropdownMenuEntry
- Configuration for a single entry in a DropdownMenu.
- StacDropdownMenuParser
- StacDuration
- A Stac model representing Flutter's Duration class.
- StacDynamicView
- A Stac model for dynamically fetching data and rendering it using a template.
- StacDynamicViewParser
- StacEdgeInsets
- A Stac representation of edge insets for padding and margins.
- StacElement
- Base interface for all STAC elements that can be serialized to JSON
- StacElevatedButton
- A Stac model representing Flutter's ElevatedButton widget.
- StacElevatedButtonParser
- StacExpanded
- A Stac model representing Flutter's Expanded widget.
- StacExpandedParser
- StacFilledButton
- A Stac model representing Flutter's FilledButton widget.
- StacFilledButtonParser
- StacFittedBox
- A Stac widget that scales and positions its child within itself.
- StacFittedBoxParser
- StacFlexible
- A Stac model representing Flutter's Flexible widget.
- StacFlexibleParser
- StacFloatingActionButton
- A Stac model representing Flutter's FloatingActionButton widget.
- StacFloatingActionButtonParser
- StacFloatingActionButtonThemeData
- A Stac model representing Flutter's FloatingActionButtonThemeData.
- StacForm
- A Stac model representing a form scope used to coordinate input fields and actions.
- StacFormFieldValidator
- A Stac model representing a declarative form field validator.
- StacFormParser
- StacFormScope
- StacFormValidate
- A Stac action that validates form data and executes conditional actions.
- StacFractionallySizedBox
- A Stac widget that sizes its child to a fraction of the available space.
- StacFractionallySizedBoxParser
- StacGestureDetector
- A Stac model for a widget that detects gestures.
- StacGestureDetectorParser
- StacGetFormValue
- A Stac action that retrieves the value of a specific form field.
- StacGradient
- A Stac representation of gradients for visual effects.
- StacGridView
- A Stac model representing Flutter's GridView widget.
- StacGridViewParser
- StacHero
- A Stac model representing Flutter's Hero widget.
- StacHeroParser
- StacIcon
- A Stac model representing Flutter's Icon widget.
- StacIconButton
- A Stac model representing Flutter's IconButton widget.
- StacIconButtonParser
- StacIconParser
- StacIcons
- String constants for icon names usable in Stac JSON. Generated from icon_utils.dart to avoid hardcoded strings.
- StacIconThemeData
- A Stac model representing Flutter's IconThemeData.
- StacImage
- A Stac widget that displays an image.
- StacImageFilter
- A Stac model representing Flutter's ImageFilter.
- StacImageParser
- StacInkWell
- A Stac model representing Flutter's InkWell widget.
- StacInputBorder
- A Stac model for Flutter input borders.
- StacInputDecoration
- Stac model that represents Flutter's InputDecoration.
- StacInputDecorationTheme
- A Stac representation of input decoration theme properties.
- StacInputFormatter
- A Stac model representing a text input formatter rule.
- StacLimitedBox
- A Stac model representing Flutter's LimitedBox widget.
- StacLimitedBoxParser
- StacLinearProgressIndicator
- A Stac model representing Flutter's LinearProgressIndicator widget.
- StacLinearProgressIndicatorParser
- StacListTile
- A Stac model for a fixed-height row that typically contains text, a leading or trailing icon, or other widgets. This model corresponds to Flutter's ListTile widget.
- StacListTileParser
- StacListTileThemeData
- A Stac model representing Flutter's ListTileThemeData.
- StacListView
- A Stac model representing Flutter's ListView.separated widget.
- StacListViewParser
- StacMaterialBannerThemeData
- A Stac model representing Flutter's MaterialBannerThemeData.
- StacMaterialColor
- A Stac model representing Flutter's MaterialColor.
- StacModalBottomSheetAction
- Core model for the "showModalBottomSheet" action.
- StacModalBottomSheetActionParser
- StacMultiAction
- Executes multiple actions sequentially or concurrently.
- StacMultiActionParser
- A Stac action that performs navigation operations.
- A Stac model representing Flutter's Material 3 NavigationBar.
- A Stac model representing Flutter's NavigationBarThemeData.
- A Stac model representing Flutter's NavigationDestination.
- A Stac model representing Flutter's NavigationDrawerThemeData.
-
A Stac widget that displays one of its
childrenbased on the active index provided by aNavigationScope(established by a StacDefaultNavigationController). - Ergonomic navigation API for Stac.
- StacNetworkRequest
- A Stac action that performs HTTP network requests.
- StacNetworkResult
- A conditional result that maps HTTP status codes to actions.
- StacNetworkService
- StacNetworkWidget
- A Stac model representing a network-driven widget.
- StacNetworkWidgetParser
- StacNoneActionParser
- StacOffset
- A Stac representation of a 2D offset (displacement).
- StacOpacity
- A Stac model representing Flutter's Opacity widget.
- StacOpacityParser
- StacOptions
- Immutable configuration for Stac projects and exports.
- StacOutlinedButton
- A Stac model representing Flutter's OutlinedButton widget.
- StacOutlinedButtonParser
- StacPadding
- A Stac widget that adds padding around its child.
- StacPaddingParser
- StacPageView
- A Stac model representing Flutter's PageView widget.
- StacPageViewParser
-
StacParser<
T> - StacParser is an abstract class that is used to parse a JSON object into a model and then parse the model into a widget.
- StacPlaceholder
- A Stac model representing Flutter's Placeholder widget.
- StacPlaceholderParser
- StacPositioned
- A Stac widget that controls where a child of a Stack is positioned.
- StacPositionedParser
- StacRadio
- A Stac model representing Flutter's Radio and CupertinoRadio widgets.
- StacRadioGroup
- A Stac model representing a radio group scope similar to Flutter's form scope.
- StacRadioGroupParser
- StacRadioParser
- StacRect
- A Stac representation of rectangles for geometric operations.
- StacRectTween
- A Stac model representing a rectangle tween used by Hero.
- StacRefreshIndicator
- A Stac model representing Flutter's RefreshIndicator widget.
- StacRefreshIndicatorParser
- StacRegistry
- StacRoundedRectangleBorder
- A Stac model representing Flutter's RoundedRectangleBorder.
- StacRow
- A Stac widget that displays its children in a horizontal array.
- StacSafeArea
- A Stac model representing Flutter's SafeArea widget.
- StacSafeAreaParser
- StacScaffold
- A Stac widget that implements the basic material design visual layout structure.
- StacScaffoldParser
- StacScreen
- Annotation to mark methods that return StacWidget instances.
- StacScrollbarThemeData
- A Stac model representing Flutter's ScrollbarThemeData.
- StacSelectableText
- A widget that displays a string of text with a single style.
- StacSelectableTextParser
- StacService
- Internal service that manages Stac parsers, actions, and rendering.
- StacSetValue
- A Stac widget that sets values in the application state.
- StacSetValueAction
- A Stac action that sets or updates values in state.
- StacSetValueActionParser
- StacSetValueParser
- StacShadow
- A Stac representation of shadows for visual effects.
- StacShapeBorder
- Abstract base class for Stac shape borders.
- StacSingleChildScrollView
- A Stac model for a box in which a single widget can be scrolled.
- StacSingleChildScrollViewParser
- StacSize
- A Stac representation of a 2D size with width and height.
- StacSizedBox
- A Stac model representing Flutter's SizedBox widget.
- StacSizedBoxParser
- StacSlider
- A Stac model representing Flutter's Slider widget.
- StacSliderParser
- StacSliverAppBar
- A Stac model representing Flutter's SliverAppBar widget.
- StacSliverAppBarParser
- StacSliverFillRemaining
- A Stac model representing Flutter's SliverFillRemaining widget.
- StacSliverFillRemainingParser
- A Stac parser that builds a Flutter SliverFillRemaining widget.
- StacSliverGrid
- A Stac model representing Flutter's SliverGrid widget.
- StacSliverGridParser
- StacSliverList
- A Stac model representing Flutter's SliverList widget.
- StacSliverListParser
- A Stac parser that builds a Flutter SliverList widget.
- StacSliverOpacity
- A Stac model representing Flutter's SliverOpacity widget.
- StacSliverOpacityParser
- StacSliverPadding
- A Stac model representing Flutter's SliverPadding widget.
- StacSliverPaddingParser
- StacSliverSafeArea
- A Stac model representing Flutter's SliverSafeArea widget.
- StacSliverSafeAreaParser
- StacSliverToBoxAdapter
- A Stac model representing Flutter's SliverToBoxAdapter widget.
- StacSliverToBoxAdapterParser
- StacSliverVisibility
- A Stac model representing Flutter's SliverVisibility widget.
- StacSliverVisibilityParser
- StacSnackBar
- Core model for the SnackBar action.
- StacSnackBarAction
- Action button configuration for a SnackBar.
- StacSnackBarParser
- StacSnackBarThemeData
- A Stac model representing Flutter's SnackBarThemeData.
- StacSpacer
- A Stac model representing Flutter's Spacer widget.
- StacSpacerParser
- StacStack
- A Stac model representing Flutter's Stack widget.
- StacStackParser
- StacSwitch
- A Stac model representing Flutter's Switch and CupertinoSwitch widgets.
- StacSwitchParser
- StacSystemUIOverlayStyle
- A Stac representation of system UI overlay styling.
- StacTab
- A Stac model representing Flutter's Tab widget.
- StacTabBar
- A Stac model representing Flutter's TabBar widget.
- StacTabBarParser
- StacTabBarThemeData
- A Stac model representing Flutter's TabBarTheme.
- StacTabBarView
- A Stac model representing Flutter's TabBarView widget.
- StacTabBarViewParser
- StacTable
- A Stac model representing Flutter's Table widget.
- StacTableBorder
-
A Stac model describing the border to paint around a
Table. - StacTableCell
- A Stac model representing Flutter's TableCell widget.
- StacTableCellParser
- StacTableColumnWidth
- Configuration describing a single column's width behavior.
- StacTableParser
- StacTableRow
-
A single row in a
Table. - StacTabParser
- StacText
-
A Stac model representing Flutter's Text widget (and
Text.rich). - StacTextButton
- A Stac model representing Flutter's TextButton widget.
- StacTextButtonParser
- StacTextField
- A Stac model representing Flutter's TextField widget.
- StacTextFieldParser
- StacTextFormField
- A Stac model representing Flutter's TextFormField widget.
- StacTextFormFieldParser
- StacTextSpan
- A Stac representation of an immutable span of text.
- StacTextStyle
- Base interface for text styles.
- StacTextTheme
- A Stac model representing Flutter's TextTheme.
- StacTheme
- A Stac model representing Flutter's ThemeData.
- StacThemeData
- A utility class providing access to Material text theme styles.
- StacThemeRef
- Annotation to mark methods that return theme definitions.
- StacThemeTextStyle
-
A text style that references a style from
ThemeData.textTheme. - StacThemeTextStyles
- Base interface for text styles.
- StacTooltip
- A Stac model representing Flutter's Tooltip widget.
- StacTooltipThemeData
- A Stac model representing Flutter's TooltipThemeData.
- StacVerticalDivider
- A Stac model representing Flutter's VerticalDivider widget.
- StacVerticalDividerParser
- StacVisibility
- A Stac model representing Flutter's Visibility widget.
- StacVisibilityParser
- StacVisualDensity
- A Stac model representing Flutter's VisualDensity class.
- StacWidget
- Base class for all STAC widgets This is a concrete implementation that can hold raw JSON data, used primarily by JSON converters for deserialization
- StacWrap
- A Stac model representing Flutter's Wrap widget.
- StacWrapParser
Enums
- ActionType
- Enumeration of all supported action types in the Stac framework.
- Method
- HTTP methods for StacNetworkRequest.
- Navigation styles supported by StacNavigateAction.
- StacAlignment
- Fixed alignment options that do not adapt to text direction.
- StacAlignmentDirectional
- Directional alignment options that adapt to text direction.
- StacAutovalidateMode
- Mirrors Flutter's AutovalidateMode for form fields.
- StacAxis
- Axis direction options for layout widgets.
- StacBlendMode
- Blend modes for compositing colors and images.
- StacBlurStyle
- Blur style options for image filters and effects.
- StacBorderStyle
- Border style options for drawing borders.
- Enum mirroring Flutter's BottomNavigationBarLandscapeLayout.
- Enum mirroring Flutter's BottomNavigationBarType.
- StacBoxFit
- How a box should be inscribed into another box.
- StacBoxShape
- Shape options for boxes and containers.
- StacBrightness
- Mirrors Flutter's Brightness.
- StacButtonBarLayoutBehavior
- Button bar layout behavior options.
- StacButtonTextTheme
- Button text theme options.
- StacCacheStrategy
- Defines different cache strategies for Stac screens.
- StacCarouselViewType
-
Defines how a
CarouselViewlays out its children. - StacClip
- Clipping options for widgets that may overflow their bounds.
- StacCrossAxisAlignment
- Cross-axis alignment options for flex layouts.
- StacDismissDirection
- Direction(s) in which a dismissible widget can be dismissed.
- StacDragStartBehavior
- Behavior options for when drag operations should start.
- StacDropdownMenuCloseBehavior
- Controls how a DropdownMenu responds to taps outside of it.
- StacFilterQuality
- Filter quality options for image scaling and rendering.
- StacFlexFit
- Flex fit options for flexible widgets.
- StacFloatingActionButtonLocation
- Floating action button positioning options.
- StacFloatingActionButtonType
- Enum representing the different types of floating action buttons.
- StacFontStyle
- Font style options for text styling.
- StacFontWeight
- Font weight options for text styling.
- StacGradientType
- Types of gradients supported by the Stac framework.
- StacHitTestBehavior
- How to behave during hit testing. Corresponds to Flutter's HitTestBehavior.
- StacIconAlignment
- Icon alignment options for buttons.
- StacIconType
- Icon design system types supported by Stac.
- StacImageFilterType
- Types of image filters supported by the Stac framework.
- StacImageRepeat
- How to paint any portions of a box not covered by an image.
- StacImageType
- Image source types supported by Stac.
- StacInputBorderType
- Type of input border to render.
- StacInputFormatterType
- Input formatter behavior types for text field validation.
- StacListTileStyle
- Defines the visual properties of a ListTile.
- StacListTileTitleAlignment
- Defines how the title and subtitle of a ListTile are vertically aligned.
- StacMainAxisAlignment
- Main-axis alignment options for flex layouts.
- StacMainAxisSize
- Main-axis sizing options for flex layouts.
- StacMaterialTapTargetSize
- Material tap target size options.
- StacMaterialTextStyle
- Material TextTheme style keys.
- StacMaxLengthEnforcement
- Mirrors Flutter's MaxLengthEnforcement for text input.
- StacMouseCursor
- Mouse cursor styles that can be applied to interactive elements.
- Navigation destination label behavior options.
- StacOptionsViewOpenDirection
- Indicates the direction in which the options view opens for Autocomplete.
- StacOverflowBarAlignment
- How children within an OverflowBar should be placed horizontally.
- StacRadioType
- Defines which platform style of radio to render.
- StacRectType
- Types of rectangle construction methods supported by StacRect.
- StacRefreshIndicatorTriggerMode
- Defines how the StacRefreshIndicator can be triggered, mirroring Flutter's RefreshIndicatorTriggerMode.
- StacScrollPhysics
- Defines the types of scroll physics that can be applied to scrollable widgets.
- StacScrollViewKeyboardDismissBehavior
- Defines how a scroll view in Stac should dismiss the keyboard.
- StacShapeBorderType
- Types of shape borders supported by the Stac framework.
- StacSliderInteraction
- Declarative enum mirroring Flutter's SliderInteraction.
- StacSliderType
- An enum to select which platform style of Slider to render.
- StacSmartDashesType
- Mirrors Flutter's SmartDashesType for text input.
- StacSmartQuotesType
- Mirrors Flutter's SmartQuotesType for text input.
- StacSnackBarBehavior
- Behavior of a SnackBar's position.
- StacStackFit
- Sizing options for Stack widget children.
- StacStrokeCap
- Stroke cap styles for line endings.
- StacSwitchType
- Defines which platform style of switch to render.
- StacTabAlignment
- Controls how tabs are aligned within a TabBar.
- StacTabBarIndicatorSize
- Defines how the tab indicator's size is computed.
- StacTableCellVerticalAlignment
- Vertical alignment options for table cells.
- StacTableColumnWidthType
-
Column width strategies supported by
Table. - StacTextAlign
- Text alignment options for text widgets.
- StacTextBaseline
- Text baseline options for vertical text alignment.
- StacTextCapitalization
- How to auto-capitalize user input. Mirrors Flutter's TextCapitalization.
- StacTextDecorationLine
- Line painted on text (maps to Flutter TextDecoration).
- StacTextDecorationStyle
- Text decoration style options for underlines, overlines, etc.
- StacTextDirection
- Text direction options for text layout.
- StacTextInputAction
- IME action button to display/trigger on the soft keyboard. Mirrors Flutter's TextInputAction.
- StacTextInputType
- JSON-friendly keyboard type values for TextField. Mirrors Flutter's TextInputType at a high level.
- StacTextLeadingDistribution
- Text leading (line height) distribution options.
- StacTextOverflow
- Text overflow handling options when text doesn't fit.
- StacTextStyleType
- Discriminator for StacTextStyle variants.
- StacTextWidthBasis
- Text width calculation basis options.
- StacTileMode
- Tile modes that determine how gradients handle areas outside their defined bounds.
- StacTooltipTriggerMode
- Defines the interaction method that triggers a tooltip, mirroring Flutter's TooltipTriggerMode.
- StacTraversalEdgeBehavior
- Dialog traversal behavior within focus traversal.
- StacVerticalDirection
- Vertical direction options for layout widgets.
- StacWrapAlignment
- Alignment options for Wrap widget children.
- StacWrapCrossAlignment
- Cross-axis alignment options for Wrap widget runs.
- WidgetType
- Enumeration of all supported widget types in the Stac framework.
Extensions
- ColorExt on String?
- StacActionParserExtension on StacAction?
- StacAlignmentDirectionalParser on StacAlignmentDirectional
- StacAlignmentGeometryParser on StacAlignmentGeometry
- StacAlignmentParser on StacAlignment
- StacAppBarThemeParser on StacAppBarTheme
- Parser extension for StacAppBarTheme.
- StacAutovalidateModeParser on StacAutovalidateMode
- Extends StacAutovalidateMode to provide parsing functionality.
- StacAxisParser on StacAxis
- StacBeveledRectangleBorderParser on StacBeveledRectangleBorder
- StacBlendModeParser on StacBlendMode
- StacBlurStyleParser on StacBlurStyle
- StacBorderParser on StacBorder
- StacBorderRadiusParser on StacBorderRadius
- StacBorderSideParser on StacBorderSide
- StacBorderStyleParser on StacBorderStyle
- StacBottomAppBarThemeParser on StacBottomAppBarThemeData
- Parser extension for StacBottomAppBarThemeData.
- Parser extension for StacBottomNavBarThemeData.
- StacBottomSheetThemeDataParser on StacBottomSheetThemeData
- Parser extension for StacBottomSheetThemeData.
- StacBoxConstraintsParser on StacBoxConstraints
- StacBoxDecorationParser on StacBoxDecoration
- StacBoxFitParser on StacBoxFit
- StacBoxShadowParser on StacBoxShadow
- StacBoxShapeParser on StacBoxShape
- StacBrightnessParser on StacBrightness
- StacButtonBarLayoutBehaviorParser on StacButtonBarLayoutBehavior
- Parser extension for StacButtonBarLayoutBehavior.
- StacButtonStyleParser on StacButtonStyle
- StacButtonTextThemeParser on StacButtonTextTheme
- Parser extension for StacButtonTextTheme.
- StacButtonThemeDataParser on StacButtonThemeData
- Parser extension for StacButtonThemeData.
- StacCardThemeDataParser on StacCardThemeData
- Parser extension for StacCardThemeData.
- StacCheckboxThemeDataParser on StacCheckboxThemeData
- Parser extension for StacCheckboxThemeData.
- StacChipThemeDataParser on StacChipThemeData
- Parser extension for StacChipThemeData.
- StacCircleBorderParser on StacCircleBorder
- StacClipParser on StacClip
- StacColorExtension on StacColor
- Extension on StacColor to provide additional functionality.
- StacColorSchemeParser on StacColorScheme
- Parser extension for StacColorScheme.
- StacContinuousRectangleBorderParser on StacContinuousRectangleBorder
- StacCrossAxisAlignmentParser on StacCrossAxisAlignment
- StacDatePickerThemeDataParser on StacDatePickerThemeData
- Parser extension for StacDatePickerThemeData.
- StacDecorationImageParser on StacDecorationImage
- StacDialogThemeParser on StacDialogTheme
- Parser extension for StacDialogTheme.
- StacDismissDirectionParser on StacDismissDirection?
- Extends StacDismissDirection to map to Flutter's DismissDirection.
- StacDividerThemeDataParser on StacDividerThemeData
- Parser extension for StacDividerThemeData.
- StacDragStartBehaviorParser on StacDragStartBehavior
- StacDrawerThemeDataParser on StacDrawerThemeData
- Parser extension for StacDrawerThemeData.
- StacDropdownMenuEntryParser on StacDropdownMenuEntry?
- StacDurationParser on StacDuration
- StacEdgeInsetsParser on StacEdgeInsets
- StacFilterQualityParser on StacFilterQuality
- StacFlexFitParser on StacFlexFit
- StacFloatingActionButtonLocationParser on StacFloatingActionButtonLocation
- StacFloatingActionThemeParser on StacFloatingActionButtonThemeData
- Parser extension for StacFloatingActionButtonThemeData.
- StacFontStyleParser on StacFontStyle
- StacFontWeightParser on StacFontWeight
- StacGradientParser on StacGradient
- StacHitTestBehaviorParser on StacHitTestBehavior
- Extends StacHitTestBehavior to provide parsing functionality.
- StacIconAlignmentParser on StacIconAlignment
- StacIconThemeDataParser on StacIconThemeData
- Parser extension for StacIconThemeData.
- StacImageFilterParser on StacImageFilter
- StacImageRepeatParser on StacImageRepeat
- StacInputBorderParser on StacInputBorder?
- StacInputDecorationParser on StacInputDecoration
- StacInputDecorationThemeParser on StacInputDecorationTheme?
- StacInputFormatterTypeCoreParser on StacInputFormatterType
- StacListTileStyleParser on StacListTileStyle
- Extends StacListTileStyle to provide parsing functionality.
- StacListTileThemeDataParser on StacListTileThemeData
- Parser extension for StacListTileThemeData.
- StacListTileTitleAlignmentParser on StacListTileTitleAlignment
- Extends StacListTileTitleAlignment to provide parsing functionality.
- StacMainAxisAlignmentParser on StacMainAxisAlignment
- StacMainAxisSizeParser on StacMainAxisSize
- StacMaterialBannerThemeDataParser on StacMaterialBannerThemeData
- Parser extension for StacMaterialBannerThemeData.
- StacMaterialColorParser on StacMaterialColor
- Parser extension for StacMaterialColor.
- StacMaterialTapTargetSizeParser on StacMaterialTapTargetSize
- StacMaxLengthEnforcementParser on StacMaxLengthEnforcement
- StacMouseCursorParser on StacMouseCursor
- Parser extension for StacNavigationBarThemeData.
- Parser extension for StacNavigationDestinationLabelBehavior.
- Parser extension for StacNavigationDrawerThemeData.
- StacOffsetParser on StacOffset
- StacOptionsViewOpenDirectionParser on StacOptionsViewOpenDirection
- StacOverflowBarAlignmentParser on StacOverflowBarAlignment
- StacRectParser on StacRect
- StacRectTweenParser on StacRectTween
- StacRefreshIndicatorTriggerModeParser on StacRefreshIndicatorTriggerMode
- Extends StacRefreshIndicatorTriggerMode to provide parsing functionality.
- StacRoundedRectangleBorderParser on StacRoundedRectangleBorder
- StacScrollbarThemeDataParser on StacScrollbarThemeData
- Parser extension for StacScrollbarThemeData.
- StacScrollPhysicsEnumParser on StacScrollPhysics
- Extends StacScrollPhysics enum to provide parsing functionality.
- StacScrollViewKeyboardDismissBehaviorParser on StacScrollViewKeyboardDismissBehavior
- Extends StacScrollViewKeyboardDismissBehavior to provide parsing functionality.
- StacShadowParser on StacShadow
- StacShapeBorderParser on StacShapeBorder
- StacSizeParser on StacSize
- StacSliderInteractionParser on StacSliderInteraction
- StacSmartDashesTypeParser on StacSmartDashesType
- StacSmartQuotesTypeParser on StacSmartQuotesType
- StacSnackBarBehaviorParser on StacSnackBarBehavior?
- Extends StacSnackBarBehavior to map to Flutter's SnackBarBehavior.
- StacSnackBarThemeDataParser on StacSnackBarThemeData
- Parser extension for StacSnackBarThemeData.
- StacStackFitParser on StacStackFit
- StacStrokeCapParser on StacStrokeCap?
- StacSwitchTypeParser on StacSwitchType
- StacSystemUIOverlayStyleParser on StacSystemUIOverlayStyle
- StacTabAlignmentParser on StacTabAlignment
- StacTabBarIndicatorSizeParser on StacTabBarIndicatorSize
- StacTabBarThemeDataParser on StacTabBarThemeData
- Parser extension for StacTabBarThemeData.
- StacTableBorderParser on StacTableBorder
- Parses a StacTableBorder to a Flutter TableBorder.
- StacTableCellVerticalAlignmentParser on StacTableCellVerticalAlignment?
- Maps StacTableCellVerticalAlignment to Flutter's TableCellVerticalAlignment.
- StacTableColumnWidthParser on StacTableColumnWidth
- Parses a StacTableColumnWidth to a Flutter TableColumnWidth.
- StacTableRowParser on StacTableRow
- Parses a StacTableRow to a Flutter TableRow.
- StacTextAlignParser on StacTextAlign
- StacTextBaselineParser on StacTextBaseline
- Maps StacTextBaseline to Flutter's TextBaseline.
- StacTextCapitalizationParser on StacTextCapitalization
- StacTextDecorationStyleParser on StacTextDecorationStyle
- StacTextDirectionParser on StacTextDirection
- StacTextInputActionParser on StacTextInputAction
- StacTextInputTypeParser on StacTextInputType
- StacTextLeadingDistributionParser on StacTextLeadingDistribution
- StacTextOverflowParser on StacTextOverflow
- StacTextStyleParser on StacTextStyle
- StacTextThemeParser on StacTextTheme
- Parser extension for StacTextTheme.
- StacTextWidthBasisParser on StacTextWidthBasis
- StacThemeParser on StacTheme
- Parser extension for StacTheme.
- StacTileModeParser on StacTileMode
- StacTooltipThemeDataParser on StacTooltipThemeData
- Parser extension for StacTooltipThemeData.
- StacTooltipTriggerModeParser on StacTooltipTriggerMode
- Extends StacTooltipTriggerMode to provide parsing functionality.
- StacTraversalEdgeBehaviorParser on StacTraversalEdgeBehavior?
- Extends StacTraversalEdgeBehavior to provide parsing functionality.
- StacVerticalDirectionParser on StacVerticalDirection
- StacVisualDensityParser on StacVisualDensity
-
StacWidgetListParser
on List<
StacWidget> ? - StacWidgetParser on StacWidget?
- StacWrapAlignmentParser on StacWrapAlignment
- StacWrapCrossAlignmentParser on StacWrapCrossAlignment
Constants
-
StacLinearGradient
→ const StacGradient Function({StacAlignment? begin, required List<
StacColor> ? colors, StacAlignment? end, List<double> ? stops, StacTileMode? tileMode}) - A linear gradient that transitions colors along a straight line.
-
StacRadialGradient
→ const StacGradient Function({StacAlignment? center, required List<
StacColor> ? colors, StacAlignment? focal, double? focalRadius, double? radius, List<double> ? stops, StacTileMode? tileMode}) - A radial gradient that transitions colors in a circular pattern from center outward.
-
StacSweepGradient
→ const StacGradient Function({StacAlignment? center, required List<
StacColor> ? colors, double? endAngle, double? startAngle, List<double> ? stops, StacTileMode? tileMode}) - A sweep gradient that transitions colors in a circular sweep around a center point.
Typedefs
- Deprecated. Use NavigationController instead.
- Deprecated. Use NavigationScope instead.
- ErrorWidgetBuilder = Widget Function(BuildContext context, dynamic error)
- Builder function for displaying errors in Stac widgets.
- LoadingWidgetBuilder = Widget Function(BuildContext context)
- Builder function for displaying loading states in Stac widgets.
- StacColor = String
- Type alias for Stac color representation as a hex string.
- StacErrorWidgetBuilder = Widget Function(BuildContext context, StacError errorDetails)
- Global parse-error widget builder for Stac.