StacBottomNavBarThemeData class
A Stac model representing Flutter's BottomNavigationBarThemeData.
Defines the theme for bottom navigation bars, including colors, icon themes, text styles, and layout properties.
{@tool snippet} Dart Example:
StacBottomNavBarThemeData(
backgroundColor: '#FFFFFF',
selectedItemColor: '#2196F3',
unselectedItemColor: '#757575',
type: BottomNavigationBarType.fixed,
)
{@end-tool}
{@tool snippet} JSON Example:
{
"backgroundColor": "#FFFFFF",
"elevation": 8.0,
"selectedItemColor": "#2196F3",
"unselectedItemColor": "#757575",
"type": "fixed",
"showSelectedLabels": true,
"showUnselectedLabels": true
}
{@end-tool}
- Implemented types
- Available extensions
- Annotations
-
- @JsonSerializable.new()
Constructors
-
Creates a StacBottomNavBarThemeData with the given properties.
const
-
Creates a StacBottomNavBarThemeData from JSON.
factory
Properties
- backgroundColor → String?
-
The background color of the bottom navigation bar.
final
- elevation → double?
-
The z-coordinate at which to place this bottom navigation bar relative to its parent.
final
- enableFeedback → bool?
-
Whether detected gestures should provide acoustic and/or haptic feedback.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- landscapeLayout → StacBottomNavigationBarLandscapeLayout?
-
The layout behavior in landscape orientation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIconTheme → StacIconThemeData?
-
The icon theme for selected items.
final
- selectedItemColor → String?
-
The color of the selected item.
final
- selectedLabelStyle → StacTextStyle?
-
The text style for selected labels.
final
- showSelectedLabels → bool?
-
Whether to show labels for selected items.
final
- showUnselectedLabels → bool?
-
Whether to show labels for unselected items.
final
- type → StacBottomNavigationBarType?
-
The type of bottom navigation bar.
final
- unselectedIconTheme → StacIconThemeData?
-
The icon theme for unselected items.
final
- unselectedItemColor → String?
-
The color of the unselected items.
final
- unselectedLabelStyle → StacTextStyle?
-
The text style for unselected labels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
BuildContext context) → BottomNavigationBarThemeData -
Available on StacBottomNavBarThemeData, provided by the StacBottomNavBarThemeDataParser extension
-
toJson(
) → Map< String, dynamic> -
Converts this bottom navigation bar theme to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited