StacDropdownMenuEntry class
Configuration for a single entry in a DropdownMenu.
- Inheritance
-
- Object
- StacElement
- StacDropdownMenuEntry
- Available extensions
- Annotations
-
- @JsonSerializable.new()
Constructors
- StacDropdownMenuEntry({dynamic value, String label = '', StacWidget? labelWidget, StacWidget? leadingIcon, StacWidget? trailingIcon, bool? enabled, StacButtonStyle? style})
-
Creates a StacDropdownMenuEntry.
const
-
StacDropdownMenuEntry.fromJson(Map<
String, dynamic> json) -
Creates a StacDropdownMenuEntry from JSON.
factory
Properties
- enabled → bool?
-
Whether this entry is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The text label for this entry.
final
- labelWidget → StacWidget?
-
A custom label widget.
final
- leadingIcon → StacWidget?
-
An icon displayed before the label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → StacButtonStyle?
-
Optional style applied to this entry.
final
- trailingIcon → StacWidget?
-
An icon displayed after the label.
final
- value → dynamic
-
The underlying value represented by this entry.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
BuildContext context) → DropdownMenuEntry? -
Available on StacDropdownMenuEntry?, provided by the StacDropdownMenuEntryParser extension
-
toJson(
) → Map< String, dynamic> -
Converts this entry to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited