StacFloatingActionButtonLocation enum
Floating action button positioning options.
Defines where a floating action button should be positioned within a scaffold. Locations can be at the top, floating, or docked to the bottom app bar, and can be positioned at start, center, or end. Mini variants use a smaller button size.
- Inheritance
- Available extensions
Values
- startTop → const StacFloatingActionButtonLocation
-
Standard FAB at the start-top position.
- miniStartTop → const StacFloatingActionButtonLocation
-
Mini FAB at the start-top position.
- centerTop → const StacFloatingActionButtonLocation
-
Standard FAB at the center-top position.
- miniCenterTop → const StacFloatingActionButtonLocation
-
Mini FAB at the center-top position.
- endTop → const StacFloatingActionButtonLocation
-
Standard FAB at the end-top position.
- miniEndTop → const StacFloatingActionButtonLocation
-
Mini FAB at the end-top position.
- startFloat → const StacFloatingActionButtonLocation
-
Standard FAB floating at the start position.
- miniStartFloat → const StacFloatingActionButtonLocation
-
Mini FAB floating at the start position.
- centerFloat → const StacFloatingActionButtonLocation
-
Standard FAB floating at the center position.
- miniCenterFloat → const StacFloatingActionButtonLocation
-
Mini FAB floating at the center position.
- endFloat → const StacFloatingActionButtonLocation
-
Standard FAB floating at the end position.
- miniEndFloat → const StacFloatingActionButtonLocation
-
Mini FAB floating at the end position.
- startDocked → const StacFloatingActionButtonLocation
-
Standard FAB docked at the start of the bottom app bar.
- miniStartDocked → const StacFloatingActionButtonLocation
-
Mini FAB docked at the start of the bottom app bar.
- centerDocked → const StacFloatingActionButtonLocation
-
Standard FAB docked at the center of the bottom app bar.
- miniCenterDocked → const StacFloatingActionButtonLocation
-
Mini FAB docked at the center of the bottom app bar.
- endDocked → const StacFloatingActionButtonLocation
-
Standard FAB docked at the end of the bottom app bar.
- miniEndDocked → const StacFloatingActionButtonLocation
-
Mini FAB docked at the end of the bottom app bar.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - parse → FloatingActionButtonLocation
-
Available on StacFloatingActionButtonLocation, provided by the StacFloatingActionButtonLocationParser extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StacFloatingActionButtonLocation> - A constant List of the values in this enum, in order of their declaration.