StacListTileTitleAlignment enum
Defines how the title and subtitle of a ListTile are vertically aligned.
This enum is used to specify the titleAlignment property of a StacListTile.
- Inheritance
- Available extensions
Values
- titleHeight → const StacListTileTitleAlignment
-
The top of the title will be aligned with the top of the leading widget.
This is the default if StacListTile.isThreeLine is false and StacListTile.subtitle is null.
- threeLine → const StacListTileTitleAlignment
-
The title and subtitle will be aligned such that the space between the leading widget and the title/subtitle is visually balanced.
This is the default if StacListTile.isThreeLine is true.
- bottom → const StacListTileTitleAlignment
-
The bottom of the subtitle will be aligned with the bottom of the leading widget.
This is the default if StacListTile.isThreeLine is false and StacListTile.subtitle is not null.
- center → const StacListTileTitleAlignment
-
The center of the title and subtitle will be aligned with the center of the leading widget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - parse → ListTileTitleAlignment
-
Available on StacListTileTitleAlignment, provided by the StacListTileTitleAlignmentParser extension
Parses this StacListTileTitleAlignment into a Flutter ListTileTitleAlignment.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StacListTileTitleAlignment> - A constant List of the values in this enum, in order of their declaration.