StacNavigationDrawerThemeData class
A Stac model representing Flutter's NavigationDrawerThemeData.
Defines the theme for navigation drawers, including colors, elevation, indicator, icon themes, and text styles.
{@tool snippet} Dart Example:
StacNavigationDrawerThemeData(
backgroundColor: '#FFFFFF',
elevation: 16.0,
indicatorColor: '#E3F2FD',
)
{@end-tool}
{@tool snippet} JSON Example:
{
"backgroundColor": "#FFFFFF",
"elevation": 16.0,
"shadowColor": "#000000",
"surfaceTintColor": "#000000",
"indicatorColor": "#E3F2FD",
"tileHeight": 48.0
}
{@end-tool}
- Implemented types
- Available extensions
- Annotations
-
- @JsonSerializable.new()
Constructors
-
Creates a StacNavigationDrawerThemeData with the given properties.
const
-
Creates a StacNavigationDrawerThemeData from JSON.
factory
Properties
- backgroundColor → String?
-
The background color of the navigation drawer.
final
- elevation → double?
-
The z-coordinate at which to place this navigation drawer relative to its parent.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconTheme → StacIconThemeData?
-
The icon theme for navigation drawer icons.
final
- indicatorColor → String?
-
The color of the indicator for the selected destination.
final
- indicatorShape → StacShapeBorder?
-
The shape of the indicator.
final
- indicatorSize → StacSize?
-
The size of the indicator.
final
- labelTextStyle → StacTextStyle?
-
The text style for navigation drawer labels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowColor → String?
-
The color of the shadow below the navigation drawer.
final
- surfaceTintColor → String?
-
The color used to tint the surface of this navigation drawer.
final
- tileHeight → double?
-
The height of each navigation drawer tile.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
BuildContext context) → NavigationDrawerThemeData -
Available on StacNavigationDrawerThemeData, provided by the StacNavigationDrawerThemeDataParser extension
-
toJson(
) → Map< String, dynamic> -
Converts this navigation drawer theme to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited