StacParser<T> class
abstract
StacParser is an abstract class that is used to parse a JSON object into a model and then parse the model into a widget.
This is used to create a parser for each type of STAC item asset.
For example, a StacTextParser can be used to parse a STAC item asset
with a "type": "text" field into a Text widget.
- Implementers
- StacAlertDialogParser
- StacAlignParser
- StacAspectRatioParser
- StacAutoCompleteParser
- StacBackdropFilterParser
- StacBadgeParser
- StacBottomNavigationBarParser
- StacBottomNavigationViewParser
- StacCardParser
- StacCarouselViewParser
- StacCenterParser
- StacCheckBoxParser
- StacChipParser
- StacCircleAvatarParser
- StacCircularProgressIndicatorParser
- StacClipOvalParser
- StacClipRRectParser
- StacColoredBoxParser
- StacColumnParser
- StacConditionalParser
- StacContainerParser
- StacCustomScrollViewParser
- StacDefaultBottomNavigationControllerParser
- StacDefaultTabControllerParser
- StacDividerParser
- StacDrawerParser
- StacDropdownMenuParser
- StacDynamicViewParser
- StacElevatedButtonParser
- StacExpandedParser
- StacFilledButtonParser
- StacFittedBoxParser
- StacFlexibleParser
- StacFloatingActionButtonParser
- StacFormParser
- StacFractionallySizedBoxParser
- StacGestureDetectorParser
- StacGridViewParser
- StacHeroParser
- StacIconButtonParser
- StacIconParser
- StacImageParser
- StacLimitedBoxParser
- StacLinearProgressIndicatorParser
- StacListTileParser
- StacListViewParser
- StacNetworkWidgetParser
- StacOpacityParser
- StacOutlinedButtonParser
- StacPaddingParser
- StacPageViewParser
- StacPlaceholderParser
- StacPositionedParser
- StacRadioGroupParser
- StacRadioParser
- StacRefreshIndicatorParser
- StacSafeAreaParser
- StacScaffoldParser
- StacSelectableTextParser
- StacSetValueParser
- StacSingleChildScrollViewParser
- StacSizedBoxParser
- StacSliderParser
- StacSliverAppBarParser
- StacSliverFillRemainingParser
- StacSliverGridParser
- StacSliverListParser
- StacSliverOpacityParser
- StacSliverPaddingParser
- StacSliverSafeAreaParser
- StacSliverToBoxAdapterParser
- StacSliverVisibilityParser
- StacSpacerParser
- StacStackParser
- StacSwitchParser
- StacTabBarParser
- StacTabBarViewParser
- StacTableCellParser
- StacTableParser
- StacTabParser
- StacTextButtonParser
- StacTextFieldParser
- StacTextFormFieldParser
- StacVerticalDividerParser
- StacVisibilityParser
- StacWrapParser
Constructors
- StacParser()
-
const
Properties
Methods
-
getModel(
Map< String, dynamic> json) → T -
Parses a JSON object into a model
T. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
BuildContext context, T model) → Widget -
Parses a model
Tinto a Widget. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited