StacScrollViewKeyboardDismissBehavior enum
Defines how a scroll view in Stac should dismiss the keyboard.
Corresponds to Flutter's ScrollViewKeyboardDismissBehavior.
- Inheritance
- Available extensions
Values
- manual → const StacScrollViewKeyboardDismissBehavior
-
The keyboard is dismissed manually.
- onDrag → const StacScrollViewKeyboardDismissBehavior
-
The keyboard is dismissed when a drag begins.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - parse → ScrollViewKeyboardDismissBehavior
-
Available on StacScrollViewKeyboardDismissBehavior, provided by the StacScrollViewKeyboardDismissBehaviorParser extension
Parses this StacScrollViewKeyboardDismissBehavior into a Flutter ScrollViewKeyboardDismissBehavior object.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StacScrollViewKeyboardDismissBehavior> - A constant List of the values in this enum, in order of their declaration.